	subroutine me_parse_initial(string, order, indices, max,
     >                              line_number)
*
* This routine will parse an initial matrix element, it should look something
* like, x, x2, xx, xyx, xxyyttpp,...
*
* 22-May-94, Pat Welch, Oregon State Univeristy (tpw@physics.orst.edu)
*
	implicit none

	character*(*) string			! matrix element string
	integer order				! order of ME
	integer max				! maximum order
	integer indices(max)			! indices of elements
	integer line_number			! line number of file

	integer length				! length of string
	integer prev_index			! previous index value
	integer i, j				! index variables
	integer multiplier			! power multiplier
	integer lnblnk				! func ret non-blank length

	order = 0				! initially zeroth order
	length = lnblnk(string)			! length of string
	if (length .eq. 0) return		! zeroth order

	prev_index = -1
	do i = 1, length
	  if ((string(i:i) .ge. '1') .and. (string(i:i) .le. '9')) then
	    if (prev_index .eq. -1) then
	      write (*,*) ' You must specify a variable before a',
     >                    ' power.'
	      if (line_number.gt.0) write (*,*) ' Line #', line_number
	      order = -1
	      return
	    endif
	    read (string(i:i), *) multiplier
	    if ((order + multiplier - 1) .gt. max) then
	      write (*,*) ' Maximum matrix element order exceeded in ',
     >                    string
	      if (line_number.gt.0) write (*,*) ' Line #', line_number
	      order = -1
	      return
	    endif
	    do j = 1, multiplier - 1
	      indices(order + j) = prev_index
	    enddo
	    order = order + multiplier - 1
	    prev_index = -1
	  else
	    prev_index = -1
	    if (string(i:i) .eq. 'x') prev_index = 1
	    if (string(i:i) .eq. 'y') prev_index = 3
	    if (string(i:i) .eq. 't') prev_index = 2
	    if (string(i:i) .eq. 'p') prev_index = 4
	    if (string(i:i) .eq. 'b') prev_index = 5
	    if (prev_index .eq. -1) then
	      write (*,*) ' Unrecognized initial matrix element, {',
     >                    string(i:i), '} in ', string
	      if (line_number.gt.0) write (*,*) ' Line #', line_number
	      order = -1
	      return
	    endif
	    order = order + 1
	    if (order .gt. max) then
	      write (*,*) ' Maximum matrix element order exceeded in ',
     >                    string
	      if (line_number.gt.0) write (*,*) ' Line #', line_number
	      order = -1
	      return
	    endif
	    indices(order) = prev_index
	  endif
	enddo

	end





